==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Persona/PersonaCoin/PersonaCoin.base.js <==
import '../../node_modules/core-js/modules/es.date.to-string.js';
import '../../node_modules/core-js/modules/es.object.to-string.js';
import '../../node_modules/core-js/modules/es.reflect.construct.js';
import '../../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, getRTL, getInitials } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import '../../node_modules/core-js/modules/es.symbol.js';
import '../../node_modules/core-js/modules/es.array.filter.js';
import '../../node_modules/core-js/modules/es.array.for-each.js';
import '../../node_modules/core-js/modules/es.object.define-properties.js';
import '../../node_modules/core-js/modules/es.object.define-property.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../../node_modules/core-js/modules/es.object.keys.js';
import '../../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { mergeStyles } from '@uifabric/merge-styles';
import '../../node_modules/core-js/modules/es.number.constructor.js';
import { ImageFit } from '../../Image/Image.types.js';
import { Image } from '../../Image/index.js';
import { Icon } from '../../Icon/index.js';
import { PersonaSize, PersonaPresence as PersonaPresence$1 } from '../Persona.types.js';
import { getPersonaInitialsColor } from '../PersonaInitialsColor.js';
import { sizeToPixels } from '../PersonaConsts.js';
import { PersonaPresence } from '../PersonaPresence/index.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction({
  cacheSize: 100
});

var PersonaCoinBase = function (_BaseComponent) {
  _inherits(PersonaCoinBase, _BaseComponent);

  var _super = _createSuper(PersonaCoinBase);

  function PersonaCoinBase() {
    var _this;

    _classCallCheck(this, PersonaCoinBase);

    _this = _super.apply(this, arguments);
    _this.mergeStyles = mergeStyles;
    _this.getPersonaInitialsColor = getPersonaInitialsColor;
    _this.PersonaSize = PersonaSize;
    _this.ImageFit = ImageFit;
    return _this;
  }

  _createClass(PersonaCoinBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          size = this.size,
          initials = this.initials,
          presence = this.presence,
          personaPresenceProps = this.personaPresenceProps,
          coinSizeStyle = this.coinSizeStyle,
          shouldRenderInitials = this.shouldRenderInitials,
          showUnknownPersonaCoin = this.showUnknownPersonaCoin,
          imageUrl = this.imageUrl,
          dimension = this.dimension;
      return h("div", {
        "attrs": {
          "role": "presentation"
        },
        "class": classNames.coin
      }, [size !== PersonaSize.size8 ? h("div", {
        "attrs": {
          "role": "presentation"
        },
        "class": classNames.imageArea,
        "style": coinSizeStyle
      }, [shouldRenderInitials && h("div", {
        "class": mergeStyles(classNames.initials, !showUnknownPersonaCoin && {
          backgroundColor: getPersonaInitialsColor(this.$props)
        }),
        "style": coinSizeStyle,
        "attrs": {
          "aria-hidden": "true"
        }
      }, [initials ? h("span", [initials]) : h(Icon, {
        "attrs": {
          "icon-name": "Contact"
        }
      })]), imageUrl && h(Image, {
        "class": classNames.image,
        "attrs": {
          "image-fit": ImageFit.cover,
          "src": imageUrl,
          "width": dimension,
          "height": dimension
        }
      }), h(PersonaPresence, {
        "props": _objectSpread({}, personaPresenceProps)
      })]) : presence ? h(PersonaPresence, {
        "props": _objectSpread({}, personaPresenceProps)
      }) : h(Icon, {
        "attrs": {
          "icon-name": "Contact"
        },
        "class": classNames.size10WithoutPresenceIcon
      }), this.$slots["default"]]);
    }
  }, {
    key: "initials",
    get: function get() {
      var imageInitials = this.imageInitials,
          allowPhoneInitials = this.allowPhoneInitials,
          showUnknownPersonaCoin = this.showUnknownPersonaCoin;
      var isRTL = getRTL(this.theme);
      return imageInitials || getInitials(this.text, isRTL, allowPhoneInitials);
    }
  }, {
    key: "dimension",
    get: function get() {
      var coinSize = this.coinSize,
          size = this.size;
      return coinSize || sizeToPixels[size];
    }
  }, {
    key: "personaPresenceProps",
    get: function get() {
      var coinSize = this.coinSize,
          theme = this.theme,
          isOutOfOffice = this.isOutOfOffice,
          presence = this.presence,
          presenceTitle = this.presenceTitle,
          size = this.size;
      return {
        coinSize: coinSize,
        isOutOfOffice: isOutOfOffice,
        presence: presence,
        presenceTitle: presenceTitle,
        size: size,
        theme: theme
      };
    }
  }, {
    key: "shouldRenderInitials",
    get: function get() {
      return !this.imageUrl;
    }
  }, {
    key: "coinSizeStyle",
    get: function get() {
      var coinSize = this.coinSize;
      return coinSize ? {
        width: coinSize,
        height: coinSize
      } : undefined;
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          className = this.className,
          coinProps = this.coinProps,
          size = this.size,
          coinSize = this.coinSize,
          showUnknownPersonaCoin = this.showUnknownPersonaCoin;
      return getClassNames(styles, {
        theme: theme,
        className: coinProps && coinProps.className ? coinProps.className : className,
        size: size,
        coinSize: coinSize,
        showUnknownPersonaCoin: showUnknownPersonaCoin
      });
    }
  }]);

  return PersonaCoinBase;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PersonaCoinBase.prototype, "allowPhoneInitials", void 0);

__decorate([Prop({
  type: Number,
  "default": PersonaPresence$1.none
}), __metadata("design:type", Number)], PersonaCoinBase.prototype, "presence", void 0);

__decorate([Prop({
  type: Number,
  "default": null
}), __metadata("design:type", Number)], PersonaCoinBase.prototype, "size", void 0);

__decorate([Prop({
  type: Number,
  "default": null
}), __metadata("design:type", Number)], PersonaCoinBase.prototype, "coinSize", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "coinProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "showUnknownPersonaCoin", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "isOutOfOffice", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "presenceTitle", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "imageUrl", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "imageInitials", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "text", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "initialsColor", void 0);

PersonaCoinBase = __decorate([Component({
  inheritAttrs: false,
  components: {
    Icon: Icon,
    OImage: Image,
    PersonaPresence: PersonaPresence
  }
})], PersonaCoinBase);

export { PersonaCoinBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Persona/PersonaCoin/PersonaCoin.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, getRTL, getInitials } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { mergeStyles } from '@uifabric/merge-styles';
import 'core-js/modules/es.number.constructor';
import { ImageFit } from '../../Image/Image.types.js';
import { Image } from '../../Image/index.js';
import { Icon } from '../../Icon/index.js';
import { PersonaSize, PersonaPresence as PersonaPresence$1 } from '../Persona.types.js';
import { getPersonaInitialsColor } from '../PersonaInitialsColor.js';
import { sizeToPixels } from '../PersonaConsts.js';
import { PersonaPresence } from '../PersonaPresence/index.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction({
  cacheSize: 100
});

var PersonaCoinBase = function (_BaseComponent) {
  _inherits(PersonaCoinBase, _BaseComponent);

  var _super = _createSuper(PersonaCoinBase);

  function PersonaCoinBase() {
    var _this;

    _classCallCheck(this, PersonaCoinBase);

    _this = _super.apply(this, arguments);
    _this.mergeStyles = mergeStyles;
    _this.getPersonaInitialsColor = getPersonaInitialsColor;
    _this.PersonaSize = PersonaSize;
    _this.ImageFit = ImageFit;
    return _this;
  }

  _createClass(PersonaCoinBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          size = this.size,
          initials = this.initials,
          presence = this.presence,
          personaPresenceProps = this.personaPresenceProps,
          coinSizeStyle = this.coinSizeStyle,
          shouldRenderInitials = this.shouldRenderInitials,
          showUnknownPersonaCoin = this.showUnknownPersonaCoin,
          imageUrl = this.imageUrl,
          dimension = this.dimension;
      return h("div", {
        "attrs": {
          "role": "presentation"
        },
        "class": classNames.coin
      }, [size !== PersonaSize.size8 ? h("div", {
        "attrs": {
          "role": "presentation"
        },
        "class": classNames.imageArea,
        "style": coinSizeStyle
      }, [shouldRenderInitials && h("div", {
        "class": mergeStyles(classNames.initials, !showUnknownPersonaCoin && {
          backgroundColor: getPersonaInitialsColor(this.$props)
        }),
        "style": coinSizeStyle,
        "attrs": {
          "aria-hidden": "true"
        }
      }, [initials ? h("span", [initials]) : h(Icon, {
        "attrs": {
          "icon-name": "Contact"
        }
      })]), imageUrl && h(Image, {
        "class": classNames.image,
        "attrs": {
          "image-fit": ImageFit.cover,
          "src": imageUrl,
          "width": dimension,
          "height": dimension
        }
      }), h(PersonaPresence, {
        "props": _objectSpread({}, personaPresenceProps)
      })]) : presence ? h(PersonaPresence, {
        "props": _objectSpread({}, personaPresenceProps)
      }) : h(Icon, {
        "attrs": {
          "icon-name": "Contact"
        },
        "class": classNames.size10WithoutPresenceIcon
      }), this.$slots.default]);
    }
  }, {
    key: "initials",
    get: function get() {
      var imageInitials = this.imageInitials,
          allowPhoneInitials = this.allowPhoneInitials,
          showUnknownPersonaCoin = this.showUnknownPersonaCoin;
      var isRTL = getRTL(this.theme);
      return imageInitials || getInitials(this.text, isRTL, allowPhoneInitials);
    }
  }, {
    key: "dimension",
    get: function get() {
      var coinSize = this.coinSize,
          size = this.size;
      return coinSize || sizeToPixels[size];
    }
  }, {
    key: "personaPresenceProps",
    get: function get() {
      var coinSize = this.coinSize,
          theme = this.theme,
          isOutOfOffice = this.isOutOfOffice,
          presence = this.presence,
          presenceTitle = this.presenceTitle,
          size = this.size;
      return {
        coinSize: coinSize,
        isOutOfOffice: isOutOfOffice,
        presence: presence,
        presenceTitle: presenceTitle,
        size: size,
        theme: theme
      };
    }
  }, {
    key: "shouldRenderInitials",
    get: function get() {
      return !this.imageUrl;
    }
  }, {
    key: "coinSizeStyle",
    get: function get() {
      var coinSize = this.coinSize;
      return coinSize ? {
        width: coinSize,
        height: coinSize
      } : undefined;
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          className = this.className,
          coinProps = this.coinProps,
          size = this.size,
          coinSize = this.coinSize,
          showUnknownPersonaCoin = this.showUnknownPersonaCoin;
      return getClassNames(styles, {
        theme: theme,
        className: coinProps && coinProps.className ? coinProps.className : className,
        size: size,
        coinSize: coinSize,
        showUnknownPersonaCoin: showUnknownPersonaCoin
      });
    }
  }]);

  return PersonaCoinBase;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaCoinBase.prototype, "allowPhoneInitials", void 0);

__decorate([Prop({
  type: Number,
  default: PersonaPresence$1.none
}), __metadata("design:type", Number)], PersonaCoinBase.prototype, "presence", void 0);

__decorate([Prop({
  type: Number,
  default: null
}), __metadata("design:type", Number)], PersonaCoinBase.prototype, "size", void 0);

__decorate([Prop({
  type: Number,
  default: null
}), __metadata("design:type", Number)], PersonaCoinBase.prototype, "coinSize", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "coinProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "showUnknownPersonaCoin", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "isOutOfOffice", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "presenceTitle", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "imageUrl", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "imageInitials", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "text", void 0);

__decorate([Prop(), __metadata("design:type", Object)], PersonaCoinBase.prototype, "initialsColor", void 0);

PersonaCoinBase = __decorate([Component({
  inheritAttrs: false,
  components: {
    Icon: Icon,
    OImage: Image,
    PersonaPresence: PersonaPresence
  }
})], PersonaCoinBase);

export { PersonaCoinBase };
